@@ -18,12 +18,8 @@ from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_kinesisanalyticsv2.paginator import (
-    ListApplicationSnapshotsPaginator,
-    ListApplicationsPaginator,
-)
-
-from .literals import RuntimeEnvironment
+from .literals import RuntimeEnvironmentType
+from .paginator import ListApplicationSnapshotsPaginator, ListApplicationsPaginator
 from .type_defs import (
     AddApplicationCloudWatchLoggingOptionResponseTypeDef,
     AddApplicationInputProcessingConfigurationResponseTypeDef,
@@ -102,7 +98,7 @@ class Exceptions:
 
 class KinesisAnalyticsV2Client:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -117,16 +113,16 @@ class KinesisAnalyticsV2Client:
         ConditionalToken: str = None,
     ) -> AddApplicationCloudWatchLoggingOptionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_cloud_watch_logging_option)
-        [Show boto3-stubs documentation](./client.md#add-application-cloud-watch-logging-option)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_cloud_watch_logging_option)
+        [Show boto3-stubs documentation](./client.md#add_application_cloud_watch_logging_option)
         """
 
     def add_application_input(
         self, ApplicationName: str, CurrentApplicationVersionId: int, Input: "InputTypeDef"
     ) -> AddApplicationInputResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_input)
-        [Show boto3-stubs documentation](./client.md#add-application-input)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_input)
+        [Show boto3-stubs documentation](./client.md#add_application_input)
         """
 
     def add_application_input_processing_configuration(
@@ -137,16 +133,16 @@ class KinesisAnalyticsV2Client:
         InputProcessingConfiguration: "InputProcessingConfigurationTypeDef",
     ) -> AddApplicationInputProcessingConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_input_processing_configuration)
-        [Show boto3-stubs documentation](./client.md#add-application-input-processing-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_input_processing_configuration)
+        [Show boto3-stubs documentation](./client.md#add_application_input_processing_configuration)
         """
 
     def add_application_output(
         self, ApplicationName: str, CurrentApplicationVersionId: int, Output: "OutputTypeDef"
     ) -> AddApplicationOutputResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_output)
-        [Show boto3-stubs documentation](./client.md#add-application-output)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_output)
+        [Show boto3-stubs documentation](./client.md#add_application_output)
         """
 
     def add_application_reference_data_source(
@@ -156,8 +152,8 @@ class KinesisAnalyticsV2Client:
         ReferenceDataSource: "ReferenceDataSourceTypeDef",
     ) -> AddApplicationReferenceDataSourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_reference_data_source)
-        [Show boto3-stubs documentation](./client.md#add-application-reference-data-source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_reference_data_source)
+        [Show boto3-stubs documentation](./client.md#add_application_reference_data_source)
         """
 
     def add_application_vpc_configuration(
@@ -168,20 +164,20 @@ class KinesisAnalyticsV2Client:
         ConditionalToken: str = None,
     ) -> AddApplicationVpcConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_vpc_configuration)
-        [Show boto3-stubs documentation](./client.md#add-application-vpc-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.add_application_vpc_configuration)
+        [Show boto3-stubs documentation](./client.md#add_application_vpc_configuration)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def create_application(
         self,
         ApplicationName: str,
-        RuntimeEnvironment: RuntimeEnvironment,
+        RuntimeEnvironment: RuntimeEnvironmentType,
         ServiceExecutionRole: str,
         ApplicationDescription: str = None,
         ApplicationConfiguration: ApplicationConfigurationTypeDef = None,
@@ -189,8 +185,8 @@ class KinesisAnalyticsV2Client:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateApplicationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.create_application)
-        [Show boto3-stubs documentation](./client.md#create-application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.create_application)
+        [Show boto3-stubs documentation](./client.md#create_application)
         """
 
     def create_application_presigned_url(
@@ -200,22 +196,22 @@ class KinesisAnalyticsV2Client:
         SessionExpirationDurationInSeconds: int = None,
     ) -> CreateApplicationPresignedUrlResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.create_application_presigned_url)
-        [Show boto3-stubs documentation](./client.md#create-application-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.create_application_presigned_url)
+        [Show boto3-stubs documentation](./client.md#create_application_presigned_url)
         """
 
     def create_application_snapshot(
         self, ApplicationName: str, SnapshotName: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.create_application_snapshot)
-        [Show boto3-stubs documentation](./client.md#create-application-snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.create_application_snapshot)
+        [Show boto3-stubs documentation](./client.md#create_application_snapshot)
         """
 
     def delete_application(self, ApplicationName: str, CreateTimestamp: datetime) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application)
-        [Show boto3-stubs documentation](./client.md#delete-application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application)
+        [Show boto3-stubs documentation](./client.md#delete_application)
         """
 
     def delete_application_cloud_watch_logging_option(
@@ -226,40 +222,40 @@ class KinesisAnalyticsV2Client:
         ConditionalToken: str = None,
     ) -> DeleteApplicationCloudWatchLoggingOptionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_cloud_watch_logging_option)
-        [Show boto3-stubs documentation](./client.md#delete-application-cloud-watch-logging-option)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_cloud_watch_logging_option)
+        [Show boto3-stubs documentation](./client.md#delete_application_cloud_watch_logging_option)
         """
 
     def delete_application_input_processing_configuration(
         self, ApplicationName: str, CurrentApplicationVersionId: int, InputId: str
     ) -> DeleteApplicationInputProcessingConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_input_processing_configuration)
-        [Show boto3-stubs documentation](./client.md#delete-application-input-processing-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_input_processing_configuration)
+        [Show boto3-stubs documentation](./client.md#delete_application_input_processing_configuration)
         """
 
     def delete_application_output(
         self, ApplicationName: str, CurrentApplicationVersionId: int, OutputId: str
     ) -> DeleteApplicationOutputResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_output)
-        [Show boto3-stubs documentation](./client.md#delete-application-output)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_output)
+        [Show boto3-stubs documentation](./client.md#delete_application_output)
         """
 
     def delete_application_reference_data_source(
         self, ApplicationName: str, CurrentApplicationVersionId: int, ReferenceId: str
     ) -> DeleteApplicationReferenceDataSourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_reference_data_source)
-        [Show boto3-stubs documentation](./client.md#delete-application-reference-data-source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_reference_data_source)
+        [Show boto3-stubs documentation](./client.md#delete_application_reference_data_source)
         """
 
     def delete_application_snapshot(
         self, ApplicationName: str, SnapshotName: str, SnapshotCreationTimestamp: datetime
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_snapshot)
-        [Show boto3-stubs documentation](./client.md#delete-application-snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_snapshot)
+        [Show boto3-stubs documentation](./client.md#delete_application_snapshot)
         """
 
     def delete_application_vpc_configuration(
@@ -270,32 +266,32 @@ class KinesisAnalyticsV2Client:
         ConditionalToken: str = None,
     ) -> DeleteApplicationVpcConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_vpc_configuration)
-        [Show boto3-stubs documentation](./client.md#delete-application-vpc-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.delete_application_vpc_configuration)
+        [Show boto3-stubs documentation](./client.md#delete_application_vpc_configuration)
         """
 
     def describe_application(
         self, ApplicationName: str, IncludeAdditionalDetails: bool = None
     ) -> DescribeApplicationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.describe_application)
-        [Show boto3-stubs documentation](./client.md#describe-application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.describe_application)
+        [Show boto3-stubs documentation](./client.md#describe_application)
         """
 
     def describe_application_snapshot(
         self, ApplicationName: str, SnapshotName: str
     ) -> DescribeApplicationSnapshotResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.describe_application_snapshot)
-        [Show boto3-stubs documentation](./client.md#describe-application-snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.describe_application_snapshot)
+        [Show boto3-stubs documentation](./client.md#describe_application_snapshot)
         """
 
     def describe_application_version(
         self, ApplicationName: str, ApplicationVersionId: int
     ) -> DescribeApplicationVersionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.describe_application_version)
-        [Show boto3-stubs documentation](./client.md#describe-application-version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.describe_application_version)
+        [Show boto3-stubs documentation](./client.md#describe_application_version)
         """
 
     def discover_input_schema(
@@ -307,8 +303,8 @@ class KinesisAnalyticsV2Client:
         InputProcessingConfiguration: "InputProcessingConfigurationTypeDef" = None,
     ) -> DiscoverInputSchemaResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.discover_input_schema)
-        [Show boto3-stubs documentation](./client.md#discover-input-schema)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.discover_input_schema)
+        [Show boto3-stubs documentation](./client.md#discover_input_schema)
         """
 
     def generate_presigned_url(
@@ -319,72 +315,72 @@ class KinesisAnalyticsV2Client:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def list_application_snapshots(
         self, ApplicationName: str, Limit: int = None, NextToken: str = None
     ) -> ListApplicationSnapshotsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_application_snapshots)
-        [Show boto3-stubs documentation](./client.md#list-application-snapshots)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_application_snapshots)
+        [Show boto3-stubs documentation](./client.md#list_application_snapshots)
         """
 
     def list_application_versions(
         self, ApplicationName: str, Limit: int = None, NextToken: str = None
     ) -> ListApplicationVersionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_application_versions)
-        [Show boto3-stubs documentation](./client.md#list-application-versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_application_versions)
+        [Show boto3-stubs documentation](./client.md#list_application_versions)
         """
 
     def list_applications(
         self, Limit: int = None, NextToken: str = None
     ) -> ListApplicationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_applications)
-        [Show boto3-stubs documentation](./client.md#list-applications)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_applications)
+        [Show boto3-stubs documentation](./client.md#list_applications)
         """
 
     def list_tags_for_resource(self, ResourceARN: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](./client.md#list-tags-for-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
     def rollback_application(
         self, ApplicationName: str, CurrentApplicationVersionId: int
     ) -> RollbackApplicationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.rollback_application)
-        [Show boto3-stubs documentation](./client.md#rollback-application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.rollback_application)
+        [Show boto3-stubs documentation](./client.md#rollback_application)
         """
 
     def start_application(
         self, ApplicationName: str, RunConfiguration: RunConfigurationTypeDef
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.start_application)
-        [Show boto3-stubs documentation](./client.md#start-application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.start_application)
+        [Show boto3-stubs documentation](./client.md#start_application)
         """
 
     def stop_application(self, ApplicationName: str, Force: bool = None) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.stop_application)
-        [Show boto3-stubs documentation](./client.md#stop-application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.stop_application)
+        [Show boto3-stubs documentation](./client.md#stop_application)
         """
 
     def tag_resource(self, ResourceARN: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.tag_resource)
-        [Show boto3-stubs documentation](./client.md#tag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def untag_resource(self, ResourceARN: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.untag_resource)
-        [Show boto3-stubs documentation](./client.md#untag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
     def update_application(
@@ -398,8 +394,8 @@ class KinesisAnalyticsV2Client:
         ConditionalToken: str = None,
     ) -> UpdateApplicationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.update_application)
-        [Show boto3-stubs documentation](./client.md#update-application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.update_application)
+        [Show boto3-stubs documentation](./client.md#update_application)
         """
 
     def update_application_maintenance_configuration(
@@ -408,8 +404,8 @@ class KinesisAnalyticsV2Client:
         ApplicationMaintenanceConfigurationUpdate: ApplicationMaintenanceConfigurationUpdateTypeDef,
     ) -> UpdateApplicationMaintenanceConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.update_application_maintenance_configuration)
-        [Show boto3-stubs documentation](./client.md#update-application-maintenance-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Client.update_application_maintenance_configuration)
+        [Show boto3-stubs documentation](./client.md#update_application_maintenance_configuration)
         """
 
     @overload
@@ -417,7 +413,7 @@ class KinesisAnalyticsV2Client:
         self, operation_name: Literal["list_application_snapshots"]
     ) -> ListApplicationSnapshotsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Paginator.ListApplicationSnapshots)[Show boto3-stubs documentation](./paginators.md#listapplicationsnapshotspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Paginator.ListApplicationSnapshots)[Show boto3-stubs documentation](./paginators.md#listapplicationsnapshotspaginator)
         """
 
     @overload
@@ -425,5 +421,5 @@ class KinesisAnalyticsV2Client:
         self, operation_name: Literal["list_applications"]
     ) -> ListApplicationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Paginator.ListApplications)[Show boto3-stubs documentation](./paginators.md#listapplicationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kinesisanalyticsv2.html#KinesisAnalyticsV2.Paginator.ListApplications)[Show boto3-stubs documentation](./paginators.md#listapplicationspaginator)
         """
