@@ -16,16 +16,16 @@ from datetime import datetime
 from typing import IO, Any, Dict, List, Union
 
 from .literals import (
-    ApplicationRestoreType,
-    ApplicationStatus,
-    CodeContentType,
-    ConfigurationType,
-    InputStartingPosition,
-    LogLevel,
-    MetricsLevel,
-    RecordFormatType,
-    RuntimeEnvironment,
-    SnapshotStatus,
+    ApplicationRestoreTypeType,
+    ApplicationStatusType,
+    CodeContentTypeType,
+    ConfigurationTypeType,
+    InputStartingPositionType,
+    LogLevelType,
+    MetricsLevelType,
+    RecordFormatTypeType,
+    RuntimeEnvironmentType,
+    SnapshotStatusType,
 )
 
 if sys.version_info >= (3, 8):
@@ -225,7 +225,7 @@ AddApplicationVpcConfigurationResponseTypeDef = TypedDict(
 _RequiredApplicationCodeConfigurationDescriptionTypeDef = TypedDict(
     "_RequiredApplicationCodeConfigurationDescriptionTypeDef",
     {
-        "CodeContentType": CodeContentType,
+        "CodeContentType": CodeContentTypeType,
     },
 )
 _OptionalApplicationCodeConfigurationDescriptionTypeDef = TypedDict(
@@ -247,7 +247,7 @@ class ApplicationCodeConfigurationDescriptionTypeDef(
 _RequiredApplicationCodeConfigurationTypeDef = TypedDict(
     "_RequiredApplicationCodeConfigurationTypeDef",
     {
-        "CodeContentType": CodeContentType,
+        "CodeContentType": CodeContentTypeType,
     },
 )
 _OptionalApplicationCodeConfigurationTypeDef = TypedDict(
@@ -268,7 +268,7 @@ class ApplicationCodeConfigurationTypeDef(
 ApplicationCodeConfigurationUpdateTypeDef = TypedDict(
     "ApplicationCodeConfigurationUpdateTypeDef",
     {
-        "CodeContentTypeUpdate": CodeContentType,
+        "CodeContentTypeUpdate": CodeContentTypeType,
         "CodeContentUpdate": "CodeContentUpdateTypeDef",
     },
     total=False,
@@ -331,8 +331,8 @@ _RequiredApplicationDetailTypeDef = TypedDict(
     {
         "ApplicationARN": str,
         "ApplicationName": str,
-        "RuntimeEnvironment": RuntimeEnvironment,
-        "ApplicationStatus": ApplicationStatus,
+        "RuntimeEnvironment": RuntimeEnvironmentType,
+        "ApplicationStatus": ApplicationStatusType,
         "ApplicationVersionId": int,
     },
 )
@@ -379,7 +379,7 @@ ApplicationMaintenanceConfigurationUpdateTypeDef = TypedDict(
 _RequiredApplicationRestoreConfigurationTypeDef = TypedDict(
     "_RequiredApplicationRestoreConfigurationTypeDef",
     {
-        "ApplicationRestoreType": ApplicationRestoreType,
+        "ApplicationRestoreType": ApplicationRestoreTypeType,
     },
 )
 _OptionalApplicationRestoreConfigurationTypeDef = TypedDict(
@@ -423,9 +423,9 @@ ApplicationSummaryTypeDef = TypedDict(
     {
         "ApplicationName": str,
         "ApplicationARN": str,
-        "ApplicationStatus": ApplicationStatus,
+        "ApplicationStatus": ApplicationStatusType,
         "ApplicationVersionId": int,
-        "RuntimeEnvironment": RuntimeEnvironment,
+        "RuntimeEnvironment": RuntimeEnvironmentType,
     },
 )
 
@@ -433,7 +433,7 @@ ApplicationVersionSummaryTypeDef = TypedDict(
     "ApplicationVersionSummaryTypeDef",
     {
         "ApplicationVersionId": int,
-        "ApplicationStatus": ApplicationStatus,
+        "ApplicationStatus": ApplicationStatusType,
     },
 )
 
@@ -448,7 +448,7 @@ CSVMappingParametersTypeDef = TypedDict(
 CheckpointConfigurationDescriptionTypeDef = TypedDict(
     "CheckpointConfigurationDescriptionTypeDef",
     {
-        "ConfigurationType": ConfigurationType,
+        "ConfigurationType": ConfigurationTypeType,
         "CheckpointingEnabled": bool,
         "CheckpointInterval": int,
         "MinPauseBetweenCheckpoints": int,
@@ -459,7 +459,7 @@ CheckpointConfigurationDescriptionTypeDef = TypedDict(
 _RequiredCheckpointConfigurationTypeDef = TypedDict(
     "_RequiredCheckpointConfigurationTypeDef",
     {
-        "ConfigurationType": ConfigurationType,
+        "ConfigurationType": ConfigurationTypeType,
     },
 )
 _OptionalCheckpointConfigurationTypeDef = TypedDict(
@@ -482,7 +482,7 @@ class CheckpointConfigurationTypeDef(
 CheckpointConfigurationUpdateTypeDef = TypedDict(
     "CheckpointConfigurationUpdateTypeDef",
     {
-        "ConfigurationTypeUpdate": ConfigurationType,
+        "ConfigurationTypeUpdate": ConfigurationTypeType,
         "CheckpointingEnabledUpdate": bool,
         "CheckpointIntervalUpdate": int,
         "MinPauseBetweenCheckpointsUpdate": int,
@@ -658,7 +658,7 @@ DescribeApplicationVersionResponseTypeDef = TypedDict(
 DestinationSchemaTypeDef = TypedDict(
     "DestinationSchemaTypeDef",
     {
-        "RecordFormatType": RecordFormatType,
+        "RecordFormatType": RecordFormatTypeType,
     },
 )
 
@@ -835,7 +835,7 @@ InputSchemaUpdateTypeDef = TypedDict(
 InputStartingPositionConfigurationTypeDef = TypedDict(
     "InputStartingPositionConfigurationTypeDef",
     {
-        "InputStartingPosition": InputStartingPosition,
+        "InputStartingPosition": InputStartingPositionType,
     },
     total=False,
 )
@@ -1132,9 +1132,9 @@ MappingParametersTypeDef = TypedDict(
 MonitoringConfigurationDescriptionTypeDef = TypedDict(
     "MonitoringConfigurationDescriptionTypeDef",
     {
-        "ConfigurationType": ConfigurationType,
-        "MetricsLevel": MetricsLevel,
-        "LogLevel": LogLevel,
+        "ConfigurationType": ConfigurationTypeType,
+        "MetricsLevel": MetricsLevelType,
+        "LogLevel": LogLevelType,
     },
     total=False,
 )
@@ -1142,14 +1142,14 @@ MonitoringConfigurationDescriptionTypeDef = TypedDict(
 _RequiredMonitoringConfigurationTypeDef = TypedDict(
     "_RequiredMonitoringConfigurationTypeDef",
     {
-        "ConfigurationType": ConfigurationType,
+        "ConfigurationType": ConfigurationTypeType,
     },
 )
 _OptionalMonitoringConfigurationTypeDef = TypedDict(
     "_OptionalMonitoringConfigurationTypeDef",
     {
-        "MetricsLevel": MetricsLevel,
-        "LogLevel": LogLevel,
+        "MetricsLevel": MetricsLevelType,
+        "LogLevel": LogLevelType,
     },
     total=False,
 )
@@ -1164,9 +1164,9 @@ class MonitoringConfigurationTypeDef(
 MonitoringConfigurationUpdateTypeDef = TypedDict(
     "MonitoringConfigurationUpdateTypeDef",
     {
-        "ConfigurationTypeUpdate": ConfigurationType,
-        "MetricsLevelUpdate": MetricsLevel,
-        "LogLevelUpdate": LogLevel,
+        "ConfigurationTypeUpdate": ConfigurationTypeType,
+        "MetricsLevelUpdate": MetricsLevelType,
+        "LogLevelUpdate": LogLevelType,
     },
     total=False,
 )
@@ -1232,7 +1232,7 @@ PaginatorConfigTypeDef = TypedDict(
 ParallelismConfigurationDescriptionTypeDef = TypedDict(
     "ParallelismConfigurationDescriptionTypeDef",
     {
-        "ConfigurationType": ConfigurationType,
+        "ConfigurationType": ConfigurationTypeType,
         "Parallelism": int,
         "ParallelismPerKPU": int,
         "CurrentParallelism": int,
@@ -1244,7 +1244,7 @@ ParallelismConfigurationDescriptionTypeDef = TypedDict(
 _RequiredParallelismConfigurationTypeDef = TypedDict(
     "_RequiredParallelismConfigurationTypeDef",
     {
-        "ConfigurationType": ConfigurationType,
+        "ConfigurationType": ConfigurationTypeType,
     },
 )
 _OptionalParallelismConfigurationTypeDef = TypedDict(
@@ -1267,7 +1267,7 @@ class ParallelismConfigurationTypeDef(
 ParallelismConfigurationUpdateTypeDef = TypedDict(
     "ParallelismConfigurationUpdateTypeDef",
     {
-        "ConfigurationTypeUpdate": ConfigurationType,
+        "ConfigurationTypeUpdate": ConfigurationTypeType,
         "ParallelismUpdate": int,
         "ParallelismPerKPUUpdate": int,
         "AutoScalingEnabledUpdate": bool,
@@ -1306,7 +1306,7 @@ class RecordColumnTypeDef(_RequiredRecordColumnTypeDef, _OptionalRecordColumnTyp
 _RequiredRecordFormatTypeDef = TypedDict(
     "_RequiredRecordFormatTypeDef",
     {
-        "RecordFormatType": RecordFormatType,
+        "RecordFormatType": RecordFormatTypeType,
     },
 )
 _OptionalRecordFormatTypeDef = TypedDict(
@@ -1544,7 +1544,7 @@ _RequiredSnapshotDetailsTypeDef = TypedDict(
     "_RequiredSnapshotDetailsTypeDef",
     {
         "SnapshotName": str,
-        "SnapshotStatus": SnapshotStatus,
+        "SnapshotStatus": SnapshotStatusType,
         "ApplicationVersionId": int,
     },
 )
